# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LLMWorkflowCreateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'duplicated_workflow_id': 'int',
        'kernel_cluster_id': 'int',
        'kernel_resource_preset_id': 'int',
        'name': 'str',
        'permission_config': 'V1LLMPermissionConfig',
        'workflow_template_id': 'int'
    }

    attribute_map = {
        'description': 'description',
        'duplicated_workflow_id': 'duplicated_workflow_id',
        'kernel_cluster_id': 'kernel_cluster_id',
        'kernel_resource_preset_id': 'kernel_resource_preset_id',
        'name': 'name',
        'permission_config': 'permission_config',
        'workflow_template_id': 'workflow_template_id'
    }

    def __init__(self, description=None, duplicated_workflow_id=None, kernel_cluster_id=None, kernel_resource_preset_id=None, name=None, permission_config=None, workflow_template_id=None, local_vars_configuration=None):  # noqa: E501
        """LLMWorkflowCreateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self._duplicated_workflow_id = None
        self._kernel_cluster_id = None
        self._kernel_resource_preset_id = None
        self._name = None
        self._permission_config = None
        self._workflow_template_id = None
        self.discriminator = None

        if description is not None:
            self.description = description
        self.duplicated_workflow_id = duplicated_workflow_id
        self.kernel_cluster_id = kernel_cluster_id
        self.kernel_resource_preset_id = kernel_resource_preset_id
        self.name = name
        if permission_config is not None:
            self.permission_config = permission_config
        self.workflow_template_id = workflow_template_id

    @property
    def description(self):
        """Gets the description of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The description of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this LLMWorkflowCreateAPIInput.


        :param description: The description of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def duplicated_workflow_id(self):
        """Gets the duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._duplicated_workflow_id

    @duplicated_workflow_id.setter
    def duplicated_workflow_id(self, duplicated_workflow_id):
        """Sets the duplicated_workflow_id of this LLMWorkflowCreateAPIInput.


        :param duplicated_workflow_id: The duplicated_workflow_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type duplicated_workflow_id: int
        """

        self._duplicated_workflow_id = duplicated_workflow_id

    @property
    def kernel_cluster_id(self):
        """Gets the kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._kernel_cluster_id

    @kernel_cluster_id.setter
    def kernel_cluster_id(self, kernel_cluster_id):
        """Sets the kernel_cluster_id of this LLMWorkflowCreateAPIInput.


        :param kernel_cluster_id: The kernel_cluster_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type kernel_cluster_id: int
        """
        if self.local_vars_configuration.client_side_validation and kernel_cluster_id is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_cluster_id`, must not be `None`")  # noqa: E501

        self._kernel_cluster_id = kernel_cluster_id

    @property
    def kernel_resource_preset_id(self):
        """Gets the kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._kernel_resource_preset_id

    @kernel_resource_preset_id.setter
    def kernel_resource_preset_id(self, kernel_resource_preset_id):
        """Sets the kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.


        :param kernel_resource_preset_id: The kernel_resource_preset_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type kernel_resource_preset_id: int
        """
        if self.local_vars_configuration.client_side_validation and kernel_resource_preset_id is None:  # noqa: E501
            raise ValueError("Invalid value for `kernel_resource_preset_id`, must not be `None`")  # noqa: E501

        self._kernel_resource_preset_id = kernel_resource_preset_id

    @property
    def name(self):
        """Gets the name of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The name of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LLMWorkflowCreateAPIInput.


        :param name: The name of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def permission_config(self):
        """Gets the permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: V1LLMPermissionConfig
        """
        return self._permission_config

    @permission_config.setter
    def permission_config(self, permission_config):
        """Sets the permission_config of this LLMWorkflowCreateAPIInput.


        :param permission_config: The permission_config of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type permission_config: V1LLMPermissionConfig
        """

        self._permission_config = permission_config

    @property
    def workflow_template_id(self):
        """Gets the workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501


        :return: The workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :rtype: int
        """
        return self._workflow_template_id

    @workflow_template_id.setter
    def workflow_template_id(self, workflow_template_id):
        """Sets the workflow_template_id of this LLMWorkflowCreateAPIInput.


        :param workflow_template_id: The workflow_template_id of this LLMWorkflowCreateAPIInput.  # noqa: E501
        :type workflow_template_id: int
        """

        self._workflow_template_id = workflow_template_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LLMWorkflowCreateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LLMWorkflowCreateAPIInput):
            return True

        return self.to_dict() != other.to_dict()
